## Script (Python) "info_portlet_get"
##title=Handler for old URLs
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=object_=None

def find_menupage_text(context):
    """Searches through context for a menupage"""
    try:
        objects = getattr(context, "objectValues", None)
        if objects is None:
            # Context is not searchable
            return
        for item in objects():
            if getattr(item, "meta_type", None) == "MenuPage":
                if item.portal_workflow.getInfoFor(item, "review_state", "") == "published":
                    # Only published menupages should be shown.
                    return item.getText()
        return
    except Exception, value:
        return

def get_body(context):
    """Searches context and all its parents until site-root for a menupage and returns the body (text) of the closest one found. Site-root is not searched"""
    # Might be a bad idea if site-root isnt the final parent (does this ever happen?), could lock a thread.
    try:
        while getattr(context, "meta_type", None) != "Plone Site":
            text = find_menupage_text(context)
            if text is not None:
                return text
            context = context.aq_inner.aq_parent
        return ""
    except Exception, value:
        raise
        return ""

return get_body(object_ or context)



# Old setup code

from Products.Archetypes.public import listTypes
from Products.Archetypes.Extensions.utils import installTypes, install_subskin
from Products.MenuNavigation.config import PROJECTNAME, GLOBALS

from StringIO import StringIO

def install(self):
    out = StringIO()

    types = listTypes(PROJECTNAME)

    installTypes(self, out, types, PROJECTNAME)

    install_subskin(self, out, GLOBALS)

    out.write("Successfully installed %s." % PROJECTNAME)
    return out.getvalue()




from Products.Archetypes.public import BaseSchema, Schema
from Products.Archetypes.public import TextField, BooleanField
from Products.Archetypes.public import RichWidget
from Products.Archetypes.public import OrderedBaseFolder, registerType
from Products.Archetypes.Marshall import PrimaryFieldMarshaller
from Products.ATContentTypes.configuration import zconf
from config import PROJECTNAME
import AccessControl

schema = BaseSchema.copy() + Schema((
        TextField('text',
                  required=True,
                  searchable=True,
                  primary=True,
                  default_content_type = zconf.ATDocument.default_content_type,
                  default_output_type = 'text/x-html',
                  allowable_content_types = zconf.ATDocument.allowed_content_types,
                  widget = RichWidget(label="Content", allow_file_upload=zconf.ATDocument.allow_document_upload)
                  ),
        BooleanField('excludeFromNav', default=True)
        ))
schema["title"].required = False
schema["title"].widget.visible["edit"] = "invisible"
schema["title"].widget.visible["view"] = "invisible"
schema["title"].default = "Menu HTML-description"

class MenuPage(OrderedBaseFolder):
    """
    """
    schema = schema
    filter_content_types = 1
    allowed_content_types = []
    meta_type = archetype_name = "MenuPage"
    global_allow = 1
    security = AccessControl.ClassSecurityInfo()
    actions = ()

registerType(MenuPage, PROJECTNAME)



try:
    from Products.LinguaPlone.public import process_types, listTypes
    HAS_LINGUAPLONE=True
except ImportError:
    from Products.Archetypes.public import *

from Products.CMFCore import utils
from Products.CMFCore.DirectoryView import registerDirectory

from config import SKINS_DIR, GLOBALS, PROJECTNAME
from config import ADD_CONTENT_PERMISSION

registerDirectory(SKINS_DIR, GLOBALS)

def initialize(context):
    ##Import Types here to register them
    import MenuNavigation

    content_types, constructors, ftis = process_types(
        listTypes(PROJECTNAME),
        PROJECTNAME)

    utils.ContentInit(
        PROJECTNAME + ' Content',
        content_types      = content_types,
        permission         = ADD_CONTENT_PERMISSION,
        extra_constructors = constructors,
        fti                = ftis,
        ).initialize(context)

try:
    from zope.i18nmessageid import MessageFactory
except ImportError:
    from zope.i18nmessageid import MessageIDFactory as MessageFactory

#WebshopMessageFactory = MessageFactory('Products.Webshop')
MenuMessageFactory = MessageFactory('Products.MenuNavigation')
